==> bouml_2.19.5.orig.tar.gz: bouml_2.19.5/src/Tools/UmlBaseExtraClassMember.h <==
// *************************************************************************
//
// Copyright (C) 2004-2006 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef _UMLBASEEXTRACLASSMEMBER_H
#define _UMLBASEEXTRACLASSMEMBER_H

#include "UmlClassItem.h"

class UmlExtraClassMember;
class UmlClass;

class UmlBaseExtraClassMember : public UmlClassItem {
  public:
    UmlBaseExtraClassMember(void * id, const QCString & n)
      : UmlClassItem(id, n) {};
  
    // returns a new extra class member named 'name'  (the name may be empty)
    // created under the class 'parent', or the null pointer in case it cannot be created
    static UmlExtraClassMember * create(UmlClass * parent, const char * name);
    
    // returns the kind of the item
    virtual anItemKind kind();
  
#ifdef WITHCPP
    // returns TRUE if the extra member is managed as an inline operation in C++
    bool isCppInline();
    
    // to set if the extra member is managed as an inline operation in C++,
    // returns FALSE on error
    bool set_isCppInline(bool y);
    
    // returns the operation's definition in C++, notes that the declaration
    // is returned by the inherited ClassItemBase::CppDecl() operation
    const QCString & cppDef();

    // sets the operation's definition in C++, notes that the declaration
    // is set through the inherited ClassItemBase::set_CppDecl() operation
    bool set_CppDef(const char * s);
#endif
    
    // to unload the object to free memory, it will be reloaded
    // automatically if needed. args unused
    virtual void unload(bool = FALSE, bool = FALSE);
    
  private:
#ifdef WITHCPP
    bool _cpp_inline;
    QCString _cpp_def;

    virtual void read_cpp_();
#endif
};

#endif

==> bouml_3.3.4.orig.tar.gz: bouml_3.3.4/src/Tools/UmlBaseExtraClassMember.h <==
#ifndef _UMLBASEEXTRACLASSMEMBER_H
#define _UMLBASEEXTRACLASSMEMBER_H


#include "UmlClassItem.h"
#include "anItemKind.h"
#include <qcstring.h>

class UmlExtraClassMember;
class UmlClass;

// Manage the 'extra' class members to produce any code, for instance a C++ pre-processing form or a Java initialization

class UmlBaseExtraClassMember : public UmlClassItem {
  public:
    // returns a new extra class member named 'name'  (the name may be empty)
    // created under the class 'parent'
    //
    // In case it cannot be created (the name is already used or
    // invalid, 'parent' cannot contain it etc ...) return 0 in C++
    // and produce a RuntimeException in Java
    static UmlExtraClassMember * create(UmlClass * parent, const char * name);

    // returns the kind of the item
    virtual anItemKind kind();

#ifdef WITHCPP
    // returns TRUE if the extra member is managed as an inline operation in C++
    
    bool isCppInline();

    // to set if the extra member is managed as an inline operation in C++
    // 
    // On error return FALSE in C++, produce a RuntimeException in Java
    bool set_isCppInline(bool y);

    // returns the operation's definition in C++, notes that the declaration
    // is returned by the inherited ClassItemBase::CppDecl() operation
    const QCString & cppDef();

    // sets the operation's definition in C++, notes that the declaration
    // is set through the inherited ClassItemBase::set_CppDecl() operation
    //
    // On error return FALSE in C++, produce a RuntimeException in Java
    bool set_CppDef(const char * s);
#endif

    // to unload the object to free memory, it will be reloaded
    // automatically if needed. args unused
    virtual void unload(bool = FALSE, bool = FALSE);


  private:
#ifdef WITHCPP
    bool _cpp_inline;
    

    QCString _cpp_def;
#endif

  protected:
    // the constructor, do not call it yourself !!!!!!!!!!
    UmlBaseExtraClassMember(void * id, const QCString & n) : UmlClassItem(id, n) {};

#ifdef WITHCPP
    //internal, do NOT use it
    
    virtual void read_cpp_();
#endif

};

#endif
